@@ -3,9 +3,8 @@
 //! The swc crates related to the  node binding should depend on this crate.
 
 #[cfg(all(
-    target_arch = "x86_64",
-    not(target_env = "musl"),
-    not(debug_assertions)
+    not(debug_assertions),
+    not(all(target_os = "linux", target_arch = "aarch64", target_env = "musl")),
 ))]
 #[global_allocator]
 static ALLOC: mimalloc_rust::GlobalMiMalloc = mimalloc_rust::GlobalMiMalloc;
